@@ -12,10 +12,11 @@ from sanza.Crm.settings import get_default_country
 from datetime import datetime, date
 from form_utils.forms import BetterModelForm, BetterForm
 from djaloha.widgets import AlohaInput
+from django.utils import timezone
 
 class AddEntityToGroupForm(forms.Form):
     group_name = forms.CharField(label=_(u"Group name"),
-        widget=forms.TextInput(attrs={'placeholder': _(u'name of a group')})
+        widget=forms.TextInput(attrs={'size': 70, 'placeholder': _(u'start typing name and choose if exists')})
     )
     
     def __init__(self, entity, *args, **kwargs):
@@ -29,8 +30,8 @@ class AddEntityToGroupForm(forms.Form):
         return name
     
 class AddContactToGroupForm(forms.Form):
-    group_name = forms.CharField(
-        widget=forms.TextInput(attrs={'placeholder': _(u'name of a group')})
+    group_name = forms.CharField(label=_(u"Group name"),
+        widget=forms.TextInput(attrs={'size': 70, 'placeholder': _(u'start typing name and choose if exists')})
     )
     
     def __init__(self, contact, *args, **kwargs):
@@ -112,7 +113,15 @@ class _CityBasedForm(object):
                 pass
         if not self.country_id:
             cn = get_default_country()
-            self.country_id = models.Zone.objects.get(name=cn, parent__isnull=True).id
+            try:
+                default_country = models.Zone.objects.get(name=cn, parent__isnull=True)
+            except models.Zone.DoesNotExist:
+                try:
+                    zt = models.ZoneType.objects.get(type="country")
+                except models.ZoneType.DoesNotExist:
+                    zt = models.ZoneType.objects.create(type="country", name=u"Country")
+                default_country = models.Zone.objects.create(name=cn, parent=None, type=zt)
+            self.country_id = default_country.id
             
         self.fields['city'].widget = CityAutoComplete(attrs={'placeholder': _(u'Enter a city'), 'size': '80'})
         
@@ -164,7 +173,6 @@ class _CityBasedForm(object):
             except ValidationError:
                 raise
             except Exception, msg:
-                raise
                 raise ValidationError(msg)
 
 class ModelFormWithCity(BetterModelForm, _CityBasedForm):
@@ -254,8 +262,8 @@ class ActionForm(BetterModelForm):
         fields = ('type', 'subject', 'date', 'time', 'status', 'in_charge', 'contact', 'opportunity', 'detail',
             'priority', 'amount', 'number', 'done', 'display_on_board', 'planned_date', 'archived')
         fieldsets = [
-            ('name', {'fields': ['type', 'subject', 'status', 'date', 'time', 'contact', 'done', 'planned_date', 'doc_template'], 'legend': _(u'Summary')}),
-            ('details', {'fields': ['in_charge', 'opportunity', 'priority', 'amount', 'number', 'detail'], 'legend': _(u'Details')}),
+            ('name', {'fields': ['subject', 'type', 'status', 'date', 'time', 'planned_date', 'in_charge', 'opportunity'], 'legend': _(u'Summary')}),
+            ('details', {'fields': ['done', 'priority', 'contact', 'amount', 'number', 'detail'], 'legend': _(u'Details')}),
             ('address', {'fields': ['display_on_board', 'archived'], 'legend': _(u'Display')}),
         ]
 
@@ -276,9 +284,8 @@ class ActionForm(BetterModelForm):
         #else:
         #    self.fields['status'].queryset = forms.HiddenInput()
         
-        doc_templates = getattr(settings, 'SANZA_DOCUMENT_TEMPLATES', None)
-        if doc_templates:
-            self.fields['contact'].widget = forms.Select(choices=doc_templates)
+        if instance and instance.entity:
+            self.fields['contact'].widget = forms.Select(choices=[(x.id, x.fullname) for x in instance.contact_set.all()])
         else:
             self.fields['contact'].widget = forms.HiddenInput()
             
@@ -291,7 +298,9 @@ class ActionForm(BetterModelForm):
         dt = self.instance.planned_date if self.instance else self.fields['planned_date'].initial
         if dt:
             self.fields["date"].initial = dt.date()
-            self.fields["time"].initial = dt.time()
+            utc_dt = dt.replace(tzinfo=timezone.utc)
+            loc_dt = utc_dt.astimezone(timezone.get_current_timezone())
+            self.fields["time"].initial = loc_dt.time()
         
     def clean_status(self):
         t = self.cleaned_data['type']
@@ -306,7 +315,8 @@ class ActionForm(BetterModelForm):
         d = self.cleaned_data["date"]
         t = self.cleaned_data.get("time", None)
         if d:
-            return datetime.combine(d, t or datetime.min.time())
+            dt = datetime.combine(d, t or datetime.min.time())
+            return dt
         return None
     
 class OpportunityForm(BetterModelForm):
