@@ -14,6 +14,7 @@ from django_extensions.db.models import TimeStampedModel, AutoSlugField
 from django.contrib.auth.models import User
 from django.db.models.signals import post_save
 from django.utils.html import mark_safe
+from sanza.utils import now_rounded
 
 class NamedElement(models.Model):
     name = models.CharField(_(u'Name'), max_length=200)
@@ -239,6 +240,7 @@ class Entity(TimeStampedModel):
     class Meta:
         verbose_name = _(u'entity')
         verbose_name_plural = _(u'entities')
+        ordering = ('name',)
 
 class EntityRole(NamedElement):
 
@@ -420,6 +422,12 @@ class Contact(TimeStampedModel):
         return has_left + [x.name for x in self.role.all()]
         
     def __unicode__(self):
+        if self.entity.is_single_contact:
+            return self.lastname
+        return u"{0} {1} ({2})".format(self.lastname, self.firstname, self.entity.name)
+            
+    @property
+    def fullname(self):
         if not (self.firstname or self.lastname):
             if self.email:
                 return self.email
@@ -436,10 +444,6 @@ class Contact(TimeStampedModel):
             return _(u"{1}{0.firstname}{0.lastname}").format(self, title)
         
         return _(u"{1}{0.firstname} {0.lastname}").format(self, title)
-            
-    @property
-    def fullname(self):
-        return unicode(self)
 
     def save(self, *args, **kwargs):
         try:
@@ -457,6 +461,7 @@ class Contact(TimeStampedModel):
     class Meta:
         verbose_name = _(u'contact')
         verbose_name_plural = _(u'contacts')
+        ordering = ('lastname', 'firstname')
     
 class Group(TimeStampedModel):
     name = models.CharField(_(u'name'), max_length=200, unique=True, db_index=True)
@@ -563,13 +568,23 @@ class ActionType(NamedElement):
     
     subscribe_form = models.BooleanField(default=False, verbose_name=_(u'Subscribe form'),
         help_text=_(u'This action type will be proposed on the public subscribe form'))
-    set = models.ForeignKey(ActionSet, blank=True, default=None, null=True)
-    last_number = models.IntegerField(_(u'number'), default=0)
-    number_auto_generated = models.BooleanField(_(u'number'), default=False)
-    default_template = models.CharField(_(u'document template'), max_length=200, blank=True, default="")
-    allowed_status = models.ManyToManyField(ActionStatus, blank=True, default=None, null=True)
-    default_status = models.ForeignKey(ActionStatus, blank=True, default=None, null=True, related_name='type_default_status_set')
+    set = models.ForeignKey(ActionSet, blank=True, default=None, null=True, verbose_name=_(u"action set"))
+    last_number = models.IntegerField(_(u'last number'), default=0)
+    number_auto_generated = models.BooleanField(_(u'generate number automatically'), default=False)
+    default_template = models.CharField(_(u'document template'), max_length=200, blank=True, default="",
+        help_text=_(u'Action of this type will have a document with the given template'))
+    allowed_status = models.ManyToManyField(ActionStatus, blank=True, default=None, null=True,
+        help_text=_(u'Action of this type allow the given status'))
+    default_status = models.ForeignKey(ActionStatus, blank=True, default=None, null=True,
+        help_text=_(u'Default status for actions of this type'),
+        related_name='type_default_status_set')
+    is_editable = models.BooleanField(_(u'is editable'), default=True,
+        help_text=_(u'If default_template is set, define if the template has a editable content'))
 
+    def status_defined(self):
+        return self.allowed_status.count()>0
+    status_defined.short_description = _(u"Status defined")
+    
     class Meta:
         verbose_name = _(u'action type')
         verbose_name_plural = _(u'action types')
@@ -585,17 +600,17 @@ class Action(TimeStampedModel):
     )
 
     entity = models.ForeignKey(Entity, blank=True, default=None, null=True)
-    subject = models.CharField(_('subject'), max_length=200, blank=True, default="")
-    planned_date = models.DateTimeField(_('planned date'), default=None, blank=True, null=True, db_index=True)
+    subject = models.CharField(_(u'subject'), max_length=200, blank=True, default="")
+    planned_date = models.DateTimeField(_(u'planned date'), default=None, blank=True, null=True, db_index=True)
     type = models.ForeignKey(ActionType, blank=True, default=None, null=True)
-    detail = models.TextField(_('detail'), blank=True, default='')
-    priority = models.IntegerField(_('priority'), default=PRIORITY_MEDIUM, choices=PRIORITY_CHOICES)
-    opportunity = models.ForeignKey(Opportunity, blank=True, default=None, null=True)
-    contact = models.ForeignKey(Contact, blank=True, default=None, null=True)
+    detail = models.TextField(_(u'detail'), blank=True, default='')
+    priority = models.IntegerField(_(u'priority'), default=PRIORITY_MEDIUM, choices=PRIORITY_CHOICES)
+    opportunity = models.ForeignKey(Opportunity, blank=True, default=None, null=True, verbose_name=_(u'opportunity'))
+    contact = models.ForeignKey(Contact, blank=True, default=None, null=True, verbose_name=_(u'contact'))
     done = models.BooleanField(_(u'done'), default=False, db_index=True)
     done_date = models.DateTimeField(_('done date'), blank=True, null=True, default=None, db_index=True)
     in_charge = models.ForeignKey(User, verbose_name=_(u'in charge'), blank=True, null=True, default=None,
-        limit_choices_to={'first_name__regex': '.+'})
+        limit_choices_to={'is_staff': True, 'first_name__regex': '.+'})
     display_on_board = models.BooleanField(verbose_name=_(u'display on board'), default=True, db_index=True)
     archived = models.BooleanField(verbose_name=_(u'archived'), default=False, db_index=True)
     amount = models.DecimalField(_(u'amount'), default=0, max_digits=11, decimal_places=2)
@@ -604,10 +619,16 @@ class Action(TimeStampedModel):
 
     def __unicode__(self):
         return u'{0} - {1}'.format(self.planned_date, self.subject or self.type)
+    
+    def has_non_editable_document(self):
+        return self.type and self.type.default_template and (not self.type.is_editable)
+    
+    def has_editable_document(self):
+        return self.type and self.type.default_template and self.type.is_editable
         
     def save(self, *args, **kwargs):
         if not self.done_date and self.done:
-            self.done_date = datetime.now()
+            self.done_date = now_rounded()
         elif self.done_date and not self.done:
             self.done_date = None
             
@@ -633,7 +654,7 @@ class ActionDocument(models.Model):
         return reverse('crm_pdf_action_document', args=[self.action.id])
     
     def can_edit_object(self, user):
-        return user.is_staff
+        return user.is_staff and self.action.has_editable_document()
     
     def can_view_object(self, user):
         return user.is_staff
